import request from "@/utils/request";
import type { ResultV2, ResultV3 } from "@/types/request-result";

const SoftwareApi = {
  search(data: SearchParams) {
    let params = JSON.parse(JSON.stringify(data));
    if (!params.materialCode) {
      delete params.materialCode;
    }

    if (!params.snCode) {
      delete params.snCode;
    }

    if (!params.serialNumber) {
      delete params.serialNumber;
    }

    return request<any, ResultV2<SoftwareInfo>>({
      method: "GET",
      url: "software/getPage",
      params,
    });
  },

  searchSn() {
    return request<any, ResultV3<string>>({
      method: "GET",
      url: "software/getSnCodeList",
    });
  },

  searchMaterial() {
    return request<any, ResultV3<string>>({
      method: "GET",
      url: "software/getMaterialCodeList",
    });
  },

  searchSerial() {
    return request<any, ResultV3<string>>({
      method: "GET",
      url: "software/getSerialNumberList",
    });
  },

  uploadSoftware(data: FormData) {
    return request<any, UploadResult>({
      method: "POST",
      url: "software/upload",
      headers: {
        "Content-Type": "multipart/form-data"
      },
      data,
    });
  },
};
export default SoftwareApi;

export interface SoftwareInfo {
  id: number;
  snCode: string;
  serialNumber: string;
  materialCode: string;
  fileName: string;
  fileUrl: string;
  uploadUserId: string;
  uploadUserName: string;
  createTime: string;
}

export interface SearchParams {
  snCode?: string;
  materialCode?: string;
  serialNumber?: string;
  pageNum: number;
  pageSize: number;
}

export interface UploadResult {
  code: number;
  msg: string;
}
